import numpy as np
import talib as ta
import pandas as pd
from MA import *


def BOLL(Series, M, N):
    a = MA(Series, M)
    len_series = len(Series)
    close_series = []
    for i in range(len_series - M + 1):
        close_series.append(Series[i:i + M])
    upper = a + N * np.std(close_series, M)
    lower = a - N * np.std(close_series, M)
    return a, upper, lower


def talib_boll(close, m, n):
    return ta.BBANDS(close, timeperiod=m, nbdevup=n, nbdevdn=n, matype=0)


def getBBands(df, period=10, stdNbr=2):
    try:
        close = df['close']
    except Exception as ex:
        return None

    try:
        upper, middle, lower = ta.BBANDS(
            close.values,
            timeperiod=period,
            # number of non-biased standard deviations from the mean
            nbdevup=stdNbr,
            nbdevdn=stdNbr,
            # Moving average type: simple moving average here
            matype=0)
    except Exception as ex:
        return None

    data = dict(upper=upper, middle=middle, lower=lower)
    df = pd.DataFrame(data, index=df.index, columns=['upper', 'middle', 'lower']).dropna()

    return df



# -*- coding:utf-8 -*-

def MA(Series, M):
    """
    简单移动平均
    用法:MA(Series,M),Series的M日简单移动平均
    :param Series:
    :param M:
    :return:ma
    """
    len_series = len(Series)
    ma = []
    for i in range(len_series - M + 1):
        ma.append(Series[i:i + M].mean())
    return ma



from MA import *
from BOLL import *
import numpy as np


def BOLL1(CLOSE, M, N):
    a = MA(CLOSE, M)
    return a


a = [1, 2, 3.9, 4, 5, 6, 7, 8, 9, 0]
s = np.array(a)
print(s)
# print(BOLL1(s, 4, 2))

print(talib_boll(s, 4, 2))
